@@ -1,8 +1,8 @@
 make.scaled.dist <-
-function(distm,uniqueGeo,rho) {
-  if ( missing(distm) ) { ## 
+function(distMatrix,uniqueGeo,rho) {
+  if ( missing(distMatrix) ) { ## 
      if ( missing(uniqueGeo) ) {
-       mess <- pastefrom("missing(distm) && missing(uniqueGeo).",prefix="(!) From ")
+       mess <- pastefrom("missing(distMatrix) && missing(uniqueGeo).",prefix="(!) From ")
        stop(mess)
      } else {
         if (length(rho)==1) {
@@ -11,15 +11,17 @@ function(distm,uniqueGeo,rho) {
            uniqueScal<-t(t(uniqueGeo) * rho) ## valid for vectorial rho...
         } else {
           mess <- pastefrom("invalid length(rho).",prefix="(!) From ")
+          print(mess)
+          mess  <- paste("Length should be either 1 or",ncol(uniqueGeo))
           stop(mess)
         }
      }
      ## scaled.dist <- as.matrix(dist(uniqueScal))
      scaled.dist <- dist(uniqueScal) ## one can do a lot with a dist object !
   } else if (length(rho)==1) {
-     scaled.dist <- rho * distm
+     scaled.dist <- rho * distMatrix
   } else {
-    mess <- pastefrom("input 'distm' but length(rho)!=1.",prefix="(!) From ")
+    mess <- pastefrom("input 'distMatrix' but length(rho)!=1.",prefix="(!) From ")
     stop(mess)
   }
   return(scaled.dist)
